/* Copyright (c) 2000 Antonios Christofides
 *
 * sysunix.c - The Unix version of daktsys.c
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <termios.h>
#include <string.h>
#include <sys/time.h>
#include <sys/types.h>
#include <unistd.h>
#include <errno.h>
#include <time.h>
#include <fcntl.h>
#include "dakt.h"
#include "daktsys.h"

static struct termios stored_settings;

void terminal_init(void)
{
	struct termios new_settings;

	tcgetattr(0, &stored_settings);
	tcgetattr(0, &new_settings);

	/* Disable canonical mode and set buffer size to 1 byte */
	new_settings.c_lflag &= (~ICANON) & (~ECHO);
	new_settings.c_cc[VTIME] = 0;
	new_settings.c_cc[VMIN] = 1;
	tcsetattr(0, TCSANOW, &new_settings);

	/* Set no blocking for standard input */
	fcntl(0, F_SETFL, O_NONBLOCK);
}

void terminal_reset(void)
{
	tcsetattr(0, TCSANOW, &stored_settings);
}

int get_key(void)
{
  	char c;


  	return read(0, &c, 1)>0 ? (int)c : 0;
}

int read_key(void)
{
  	int i;

	while((i=getchar())<0)
	  	waitms(100);
	return i;
}

void waitms(unsigned long ms)
{
	usleep(ms*1000);
}
